summaryrefslogtreecommitdiff
path: root/app/models/namespace.rb
diff options
context:
space:
mode:
authorDmitriy Zaporozhets <dmitriy.zaporozhets@gmail.com>2015-08-11 14:29:43 +0200
committerDmitriy Zaporozhets <dmitriy.zaporozhets@gmail.com>2015-08-11 14:29:43 +0200
commitc0bf026ed8253e9bf749546e40f968dbc20aaac1 (patch)
treeadb3d8f276395f8593fdac5a6153a2a51dced654 /app/models/namespace.rb
parent7f3228ec74725c02efb0e23ff8380eaa03739891 (diff)
parent5daf44b7c86e0e2641a902b1da8b01d91fa3dbfa (diff)
downloadgitlab-ce-c0bf026ed8253e9bf749546e40f968dbc20aaac1.tar.gz
Merge branch 'master' of gitlab.com:gitlab-org/gitlab-ce
Diffstat (limited to 'app/models/namespace.rb')
-rw-r--r--app/models/namespace.rb5
1 files changed, 3 insertions, 2 deletions
diff --git a/app/models/namespace.rb b/app/models/namespace.rb
index 161a16ca61c..30ffacadded 100644
--- a/app/models/namespace.rb
+++ b/app/models/namespace.rb
@@ -118,11 +118,12 @@ class Namespace < ActiveRecord::Base
gitlab_shell.add_namespace(path_was)
if gitlab_shell.mv_namespace(path_was, path)
# If repositories moved successfully we need to
# send update instructions to users.
# However we cannot allow rollback since we moved namespace dir
# So we basically we mute exceptions in next actions
begin
+ gitlab_shell.rm_satellites(path_was)
send_update_instructions
rescue
# Returning false does not rollback after_* transaction but gives
@@ -118,11 +118,12 @@ class Namespace < ActiveRecord::Base
gitlab_shell.add_namespace(path_was)
if gitlab_shell.mv_namespace(path_was, path)
- # If repositories moved successfully we need to
- # send update instructions to users.
+ # If repositories moved successfully we need to remove old satellites
+ # and send update instructions to users.
# However we cannot allow rollback since we moved namespace dir
# So we basically we mute exceptions in next actions